pub trait PhysicalObject {
// Required method
fn compute_force(&self, position: [f32; 3]) -> [f32; 3];
}Expand description
A trait representing a physical object that can compute a force given a position.
pub trait PhysicalObject {
// Required method
fn compute_force(&self, position: [f32; 3]) -> [f32; 3];
}A trait representing a physical object that can compute a force given a position.